package com.xinda.itsm.mapper;

import java.util.List;
import com.xinda.itsm.domain.ProcessInfo;

/**
 * 流程管理Mapper接口
 *
 * @author kerwincui
 * @date 2025-04-27
 */
public interface ProcessInfoMapper
{
    /**
     * 查询流程管理
     *
     * @param processId 流程管理主键
     * @return 流程管理
     */
    public ProcessInfo selectProcessInfoByProcessId(Long processId);

    /**
     * 查询流程管理列表
     *
     * @param processInfo 流程管理
     * @return 流程管理集合
     */
    public List<ProcessInfo> selectProcessInfoList(ProcessInfo processInfo);

    /**
     * 新增流程管理
     *
     * @param processInfo 流程管理
     * @return 结果
     */
    public int insertProcessInfo(ProcessInfo processInfo);

    /**
     * 修改流程管理
     *
     * @param processInfo 流程管理
     * @return 结果
     */
    public int updateProcessInfo(ProcessInfo processInfo);

    /**
     * 删除流程管理
     *
     * @param processId 流程管理主键
     * @return 结果
     */
    public int deleteProcessInfoByProcessId(Long processId);

    /**
     * 批量删除流程管理
     *
     * @param processIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProcessInfoByProcessIds(Long[] processIds);
}
